.. _uncertaintybase:

UncertaintyBase
***************

.. autoclass:: stats_arrays.UncertaintyBase
    :members:
    :inherited-members:
    :show-inheritance:

.. _boundeduncertaintybase:

BoundedUncertaintyBase
======================

.. autoclass:: stats_arrays.BoundedUncertaintyBase
    :members:
    :inherited-members:
    :show-inheritance:
